@@ -63,17 +63,10 @@ grouped_augment <- function(data,
   }
 
   # dataframe with grouped analysis results
-  if (utils::packageVersion("dplyr") > "0.8.0.1") {
-    df_results <- data %>%
-      dplyr::group_by(.data = ., !!!grouping.vars, .drop = TRUE) %>%
-      dplyr::group_modify(.tbl = ., .f = augment_group, keep = TRUE) %>%
-      dplyr::ungroup(x = .)
-  } else {
-    df_results <- data %>%
-      dplyr::group_by(.data = ., !!!grouping.vars, .drop = TRUE) %>%
-      dplyr::group_map(.tbl = ., .f = augment_group) %>%
-      dplyr::ungroup(x = .)
-  }
+  df_results <- data %>%
+    dplyr::group_by(.data = ., !!!grouping.vars, .drop = TRUE) %>%
+    dplyr::group_modify(.tbl = ., .f = augment_group, keep = TRUE) %>%
+    dplyr::ungroup(x = .)
 
   # return the final dataframe with results
   return(df_results)
