@@ -6,7 +6,7 @@
 #' @inheritParams grouped_tidy
 #'
 #' @importFrom rlang !! !!! exec quo_squash enquo
-#' @importFrom dplyr group_by ungroup mutate group_map
+#' @importFrom dplyr group_by ungroup mutate group_map group_modify
 #' @importFrom utils packageVersion
 #'
 #' @inherit glance return value
@@ -62,17 +62,10 @@ grouped_glance <- function(data,
   }
 
   # dataframe with grouped analysis results
-  if (utils::packageVersion("dplyr") > "0.8.0.1") {
-    df_results <- data %>%
-      dplyr::group_by(.data = ., !!!grouping.vars, .drop = TRUE) %>%
-      dplyr::group_modify(.tbl = ., .f = glance_group, keep = TRUE) %>%
-      dplyr::ungroup(x = .)
-  } else {
-    df_results <- data %>%
-      dplyr::group_by(.data = ., !!!grouping.vars, .drop = TRUE) %>%
-      dplyr::group_map(.tbl = ., .f = glance_group) %>%
-      dplyr::ungroup(x = .)
-  }
+  df_results <- data %>%
+    dplyr::group_by(.data = ., !!!grouping.vars, .drop = TRUE) %>%
+    dplyr::group_modify(.tbl = ., .f = glance_group, keep = TRUE) %>%
+    dplyr::ungroup(x = .)
 
   # return the final dataframe with results
   return(df_results)
